Share and Enjoy
---------------

``Microsite`` would not have been possible without the contribution of the following people:

- Héctor Velarde
- Juan Pablo Giménez
- Érico Andrei
- `Xenatt <https://www.iconfinder.com/iconsets/minimalism>`_ (icon)

Development sponsored by `Simples Consultoria <http://www.simplesconsultoria.com.br>`_.
